@@ -167,7 +167,7 @@ class MachineBase:
             tries -= 1
         raise ConnectionError("SSH connection could not be made")
 
-    def get(self, from_path, to_path=None):
+    def get(self, from_path, to_path=None) -> str:
         """"""
 
         def cp(path):
@@ -353,10 +353,10 @@ class Machine(MachineBase):
         super().__init__(*args, **kwargs)
         # XXX self.nginx_dir = self.system_dir / "nginx"
         # XXX self.python_dir = self.system_dir / "python"
+        # XXX self.projects_dir = self.system_dir / "projects"
         self.runinenv = "/home/gaea/runinenv"
-        self.projects_dir = self.system_dir / "projects"
-        self.env_dir = "/home/gaea/app"
-        self.run_dir = f"{self.env_dir}/run"
+        self.env_dir = pathlib.Path("/home/gaea/app")
+        self.run_dir = self.env_dir / "run"
 
     def setup_python(self):
         """
@@ -404,7 +404,7 @@ class Machine(MachineBase):
             ),
         )
         self.run("service tor restart")
-        self.onion = self.get(f"{self.tor_data}/main/hostname")
+        self.onion = self.get(f"{self.tor_data}/main/hostname").strip()
 
     def setup_nginx(self):
         """
@@ -435,13 +435,14 @@ class Machine(MachineBase):
         self.user = "gaea"
 
         # streaming server
-        streaming_dir = "/home/gaea/app/run/media/streaming"
+        streaming_dir = self.run_dir / "media/streaming"
         self.run(f"mkdir {streaming_dir} -p")
         self.run(f"mkdir {streaming_dir}/hls")
         self.run(f"mkdir {streaming_dir}/rec")
 
         # self-signed TLS certificate for IP address
-        self.run(f"mkdir {self.run_dir}/certs -p")
+        certs_dir = self.run_dir / "certs"
+        self.run(f"mkdir {certs_dir} -p")
         domain_cnf = configparser.ConfigParser()
         domain_cnf.optionxform = str
         domain_cnf["req"] = {
@@ -458,14 +459,14 @@ class Machine(MachineBase):
         config_output = io.StringIO()
         domain_cnf.write(config_output)
         self.run(
-            f"cat > {self.run_dir}/certs/selfsigned-ip.cnf",
+            f"cat > {certs_dir}/selfsigned-ip.cnf",
             stdin=config_output.getvalue(),
         )
         self.run(
             "sudo openssl req -x509 -nodes -days 365 -newkey rsa:2048"
-            " -keyout /etc/ssl/private/selfsigned-ip.key"
-            " -out /etc/ssl/certs/selfsigned-ip.crt"
-            f" -config {self.run_dir}/certs/selfsigned-ip.cnf"
+            f" -keyout {certs_dir}/selfsigned-ip.key"
+            f" -out {certs_dir}/selfsigned-ip.crt"
+            f" -config {certs_dir}/selfsigned-ip.cnf"
         )
 
         self.user = "root"
@@ -480,9 +481,9 @@ class Machine(MachineBase):
         self.run("systemctl daemon-reload")
         self.run("service fcgiwrap restart")
 
-        # get onion
-        self.run("cp /var/lib/tor/main/hostname /home/gaea/app/run/onion")
-        self.run("chown gaea:gaea /home/gaea/app/run/onion")
+        self.run(f"cp /var/lib/tor/main/hostname {self.run_dir}/onion")
+        self.run(f"chown gaea:gaea {self.run_dir}/onion")
+        self.run(f"touch {self.run_dir}/domains")
 
         self.generate_dhparam(512)  # NOTE 2048 adds ? minutes
         self.run("service nginx restart")
